Class: Aws::MarketplaceDeployment::Types::PutDeploymentParameterRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacedeployment/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agreement_idString

The unique identifier of the agreement.

Returns:

  • (String)


157
158
159
160
161
162
163
164
165
166
167
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157

class PutDeploymentParameterRequest < Struct.new(
  :agreement_id,
  :catalog,
  :client_token,
  :deployment_parameter,
  :expiration_date,
  :product_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#catalogString

The catalog related to the request. Fixed value: AWSMarketplace

Returns:

  • (String)


157
158
159
160
161
162
163
164
165
166
167
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157

class PutDeploymentParameterRequest < Struct.new(
  :agreement_id,
  :catalog,
  :client_token,
  :deployment_parameter,
  :expiration_date,
  :product_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

The idempotency token for deployment parameters. A unique identifier for the new version.

This field is not required if you're calling using an AWS SDK. Otherwise, a clientToken must be provided with the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


157
158
159
160
161
162
163
164
165
166
167
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157

class PutDeploymentParameterRequest < Struct.new(
  :agreement_id,
  :catalog,
  :client_token,
  :deployment_parameter,
  :expiration_date,
  :product_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_parameterTypes::DeploymentParameterInput

The deployment parameter targeted to the acceptor of an agreement for which to create the AWS Secret Manager resource.



157
158
159
160
161
162
163
164
165
166
167
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157

class PutDeploymentParameterRequest < Struct.new(
  :agreement_id,
  :catalog,
  :client_token,
  :deployment_parameter,
  :expiration_date,
  :product_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_dateTime

The date when deployment parameters expire and are scheduled for deletion.

Returns:

  • (Time)


157
158
159
160
161
162
163
164
165
166
167
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157

class PutDeploymentParameterRequest < Struct.new(
  :agreement_id,
  :catalog,
  :client_token,
  :deployment_parameter,
  :expiration_date,
  :product_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#product_idString

The product for which AWS Marketplace will save secrets for the buyer’s account.

Returns:

  • (String)


157
158
159
160
161
162
163
164
165
166
167
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157

class PutDeploymentParameterRequest < Struct.new(
  :agreement_id,
  :catalog,
  :client_token,
  :deployment_parameter,
  :expiration_date,
  :product_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A map of key-value pairs, where each pair represents a tag saved to the resource. Tags will only be applied for create operations, and they'll be ignored if the resource already exists.

Returns:

  • (Hash<String,String>)


157
158
159
160
161
162
163
164
165
166
167
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157

class PutDeploymentParameterRequest < Struct.new(
  :agreement_id,
  :catalog,
  :client_token,
  :deployment_parameter,
  :expiration_date,
  :product_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end