Class: Aws::MarketplaceDeployment::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MarketplaceDeployment::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-marketplacedeployment/client.rb
Overview
An API client for MarketplaceDeployment. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MarketplaceDeployment::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags that have been added to a deployment parameter resource.
-
#put_deployment_parameter(params = {}) ⇒ Types::PutDeploymentParameterResponse
Creates or updates a deployment parameter and is targeted by ‘catalog` and `agreementId`.
-
#tag_resource(params = {}) ⇒ Struct
Tags a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or list of tags from a resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-marketplacedeployment/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
675 676 677 |
# File 'lib/aws-sdk-marketplacedeployment/client.rb', line 675 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
678 679 680 |
# File 'lib/aws-sdk-marketplacedeployment/client.rb', line 678 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 |
# File 'lib/aws-sdk-marketplacedeployment/client.rb', line 648 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MarketplaceDeployment') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-marketplacedeployment' context[:gem_version] = '1.35.0' Seahorse::Client::Request.new(handlers, context) end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags that have been added to a deployment parameter resource.
503 504 505 506 |
# File 'lib/aws-sdk-marketplacedeployment/client.rb', line 503 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_deployment_parameter(params = {}) ⇒ Types::PutDeploymentParameterResponse
Creates or updates a deployment parameter and is targeted by ‘catalog` and `agreementId`.
582 583 584 585 |
# File 'lib/aws-sdk-marketplacedeployment/client.rb', line 582 def put_deployment_parameter(params = {}, = {}) req = build_request(:put_deployment_parameter, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags a resource.
612 613 614 615 |
# File 'lib/aws-sdk-marketplacedeployment/client.rb', line 612 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag or list of tags from a resource.
639 640 641 642 |
# File 'lib/aws-sdk-marketplacedeployment/client.rb', line 639 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
668 669 670 |
# File 'lib/aws-sdk-marketplacedeployment/client.rb', line 668 def waiter_names [] end |