Class: Aws::MarketplaceDeployment::Types::PutDeploymentParameterRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDeployment::Types::PutDeploymentParameterRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacedeployment/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agreement_id ⇒ String
The unique identifier of the agreement.
-
#catalog ⇒ String
The catalog related to the request.
-
#client_token ⇒ String
The idempotency token for deployment parameters.
-
#deployment_parameter ⇒ Types::DeploymentParameterInput
The deployment parameter targeted to the acceptor of an agreement for which to create the AWS Secret Manager resource.
-
#expiration_date ⇒ Time
The date when deployment parameters expire and are scheduled for deletion.
-
#product_id ⇒ String
The product for which AWS Marketplace will save secrets for the buyer’s account.
-
#tags ⇒ Hash<String,String>
A map of key-value pairs, where each pair represents a tag saved to the resource.
Instance Attribute Details
#agreement_id ⇒ String
The unique identifier of the agreement.
157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157 class PutDeploymentParameterRequest < Struct.new( :agreement_id, :catalog, :client_token, :deployment_parameter, :expiration_date, :product_id, :tags) SENSITIVE = [] include Aws::Structure end |
#catalog ⇒ String
The catalog related to the request. Fixed value: AWSMarketplace
157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157 class PutDeploymentParameterRequest < Struct.new( :agreement_id, :catalog, :client_token, :deployment_parameter, :expiration_date, :product_id, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The idempotency token for deployment parameters. A unique identifier for the new version.
clientToken must be provided with the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157 class PutDeploymentParameterRequest < Struct.new( :agreement_id, :catalog, :client_token, :deployment_parameter, :expiration_date, :product_id, :tags) SENSITIVE = [] include Aws::Structure end |
#deployment_parameter ⇒ Types::DeploymentParameterInput
The deployment parameter targeted to the acceptor of an agreement for which to create the AWS Secret Manager resource.
157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157 class PutDeploymentParameterRequest < Struct.new( :agreement_id, :catalog, :client_token, :deployment_parameter, :expiration_date, :product_id, :tags) SENSITIVE = [] include Aws::Structure end |
#expiration_date ⇒ Time
The date when deployment parameters expire and are scheduled for deletion.
157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157 class PutDeploymentParameterRequest < Struct.new( :agreement_id, :catalog, :client_token, :deployment_parameter, :expiration_date, :product_id, :tags) SENSITIVE = [] include Aws::Structure end |
#product_id ⇒ String
The product for which AWS Marketplace will save secrets for the buyer’s account.
157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157 class PutDeploymentParameterRequest < Struct.new( :agreement_id, :catalog, :client_token, :deployment_parameter, :expiration_date, :product_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map of key-value pairs, where each pair represents a tag saved to the resource. Tags will only be applied for create operations, and they'll be ignored if the resource already exists.
157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/aws-sdk-marketplacedeployment/types.rb', line 157 class PutDeploymentParameterRequest < Struct.new( :agreement_id, :catalog, :client_token, :deployment_parameter, :expiration_date, :product_id, :tags) SENSITIVE = [] include Aws::Structure end |